**DATASHEET**

I combine the Datasheet image with the one from the [SpenceKonde website](https://github.com/SpenceKonde/megaTinyCore/blob/master/megaavr/extras/ATtiny_x14.md) on the ATtiny1614.

* 14 pin package.
* Two internal clocks 16 and 20 MHz.
* 16 KB Flash Memory.
* 256 B EEPROM.
* 2 KB SRAM.
* Maximum voltage: 6V; minimum voltage -0.5 V.

After looking at the basic features, you will find the pinning of the microcontroller.

![week08.04](/uploads/42085ccf768761cb72f41c66e4d2e48d/week08.04.jpg)

* VDD: Supply voltage.
* GND: Ground.
* Digital pins: Port A: PA0, PA1, PA2, PA3, PA4, PA5, PA6, PA7. Port B: PB0, PB1, PB2, PB3.
* Analog pins: PA1, PA2, PA3, PA4, PA5, PA6, PA7. Port B: PB0, PB1.
* UPDI Programming pin: PA0 (physical pin number 10).
* External Clock Pin: PA3.

All I/O pins can be configured with **internal pullup resistance**.

Within the communications section there are different types and their pins are different. It is clear that the different communication protocols cannot all be used at the same time, because they have pins in common.

* **USART** - Universal Synchronous and Asynchronous Receiver and Transmitter: It has the RX (PB2 or PA2) and the TX (PB3 or PA1).
* **SPI** - Serial Peripheral Interface: It has only MOSI (PA1), MISO (PA2), SCK (PA3), SS (PA4) .
* **TWI** - Two Wire Interface (I2C): It has SDA (PB1 or PA1) and SCL (PB0 or PA2).


Another important thing that the datasheet is telling us is that you have to keep in mind which kind of input component you are using, digital or analog: for instance, if you are using a temperature sensor (analog component) you have to connect it to an ACD (analog to digital converter) port otherwise the microcontroller isn't able to transform the information that is receiving from the sensor to a digital data.


**HELLO DISTANCE**


I am going to use a module that integrates the **VL53L0X sensor.** The module is sold by Adafruit, although in my case I bought it from Amazon.

I am going to use the ATtiny1614 to communicate with the sensor. In this case of the pinout that the sensor brings, I will only use the VCC, GND, SDA and SCL pins. 

![week09.17](/uploads/f8ff512f81ed5b4cf904785478acd8ed/week09.17.jpg)


Using Eagle I design the schematic and the board. I really only use the following pins of the ATtiny1614: VCC, GND, TX, RX, UPDI, SCL and SDA.

![week09.18](/uploads/e3657ff0a6a7ea136a74f0fe6328e401/week09.18.jpg)

Using **GIMP** I eliminate the paths that I don't need and I make the outer cut layer. And these are the two images ready to use in the Modela.

![Hello_distance_traces2](/uploads/a1d3790d8d8846f7593800cb017ea4d7/Hello_distance_traces2.png)
![Hello_distance_interior](/uploads/3e094d0078de6e4dc54ae5a96b93c68d/Hello_distance_interior.png)

And this is the result of the board, with the VL53L0X module:

![week09.24](/uploads/23a0c5e1b6940abc166bee7b7585b0e5/week09.24.jpg)

**PROGRAMMING: ARDUINO + LINUX.**

As the memory of the ATtiny1614 is limited, we must use a library that does not occupy much. There is the following [Polulu library](https://github.com/pololu/vl53l0x-arduino)

I use a code that the library had as an example, it is called "Single."

    /* This example shows how to get single-shot range
     measurements from the VL53L0X. The sensor can optionally be
     configured with different ranging profiles, as described in
     the VL53L0X API user manual, to get better performance for
     a certain application. This code is based on the four
     "SingleRanging" examples in the VL53L0X API.

     The range readings are in units of mm. */
    #include 
    #include 
    VL53L0X sensor;
    // Uncomment this line to use long range mode. This
    // increases the sensitivity of the sensor and extends its
    // potential range, but increases the likelihood of getting
    // an inaccurate reading because of reflections from objects
    // other than the intended target. It works best in dark
    // conditions.

    //#define LONG_RANGE


    // Uncomment ONE of these two lines to get
    // - higher speed at the cost of lower accuracy OR
    // - higher accuracy at the cost of lower speed

    //#define HIGH_SPEED
    //#define HIGH_ACCURACY


    void setup()
    {
      Serial.begin(115200);
      Wire.begin();

      sensor.setTimeout(500);
      if (!sensor.init())
      {
        Serial.println("Failed to detect and initialize sensor!");
        while (1) {}
      }

    #if defined LONG_RANGE
      // lower the return signal rate limit (default is 0.25 MCPS)
      sensor.setSignalRateLimit(0.1);
      // increase laser pulse periods (defaults are 14 and 10 PCLKs)
      sensor.setVcselPulsePeriod(VL53L0X::VcselPeriodPreRange, 18);
      sensor.setVcselPulsePeriod(VL53L0X::VcselPeriodFinalRange, 14);
    #endif

    #if defined HIGH_SPEED
      // reduce timing budget to 20 ms (default is about 33 ms)
      sensor.setMeasurementTimingBudget(20000);
    #elif defined HIGH_ACCURACY
      // increase timing budget to 200 ms
      sensor.setMeasurementTimingBudget(200000);
    #endif
    }

    void loop()
    {
      Serial.print(sensor.readRangeSingleMillimeters());
      if (sensor.timeoutOccurred()) { Serial.print(" TIMEOUT"); }

      Serial.println();
    }

Using the PyUPDI and the FT230XS programmer and the converter for UPDI I load the .hex program.

Program the board using python -> run 

          sudo python3 pyupdi.py -d tiny1614 -c /dev/ttyUSB0 -b 19200 -f Single_VL53L0X.ino.hex -v

After, listen the serial port 

         python -m serial.tools.miniterm /dev/ttyUSB0 115200




You can find more information about this board on my page.

http://fabacademy.org/2020/labs/leon/students/adrian-torres/week09.html