**DATASHEET**

This is the ATtiny3216. I combine the Datasheet image with the one from the [SpenceKonde website](https://github.com/SpenceKonde/megaTinyCore/blob/master/megaavr/extras/ATtiny_x16.md) on the ATtiny3216.

* 20 pin package.
* Internal clocks 1/4/5/8/10/16 20 MHz.
* 32768 bytes Flash Memory.
* 256 bytes EEPROM.
* 2048 bytes SRAM.
* Maximum voltage: 6V; minimum voltage -0.5 V.
* After looking at the basic features, you will find the pinning of the microcontroller.

After looking at the basic features, you will find the pinning of the microcontroller.

![week09.26](/uploads/b1afe75e2c69e4b16dac059ab0f1414d/week09.26.jpg)

* VDD: Supply voltage.
* GND: Ground.
* Digital pins: Port A: PA0, PA1, PA2, PA3, PA4, PA5, PA6, PA7. Port B: PB0, PB1, PB2, PB3, PB4, PB5. Port C: PC0, PC1, PC2, PC3.
* Analog pins: Port A: PA0, PA1, PA2, PA3, PA4, PA5, PA6, PA7. Port B: PB0, PB1, PB4, PB5.
* UPDI Programming pin: PA0 (physical pin number 16).

All I/O pins can be configured with **internal pullup resistance.**

Within the communications section there are different types and their pins are different. It is clear that the different communication protocols cannot all be used at the same time, because they have pins in common.

* **USART** - Universal Synchronous and Asynchronous Receiver and Transmitter: It has the RX (PB3 or PA2) and the TX (PB2 or PA1).
* **SPI** - Serial Peripheral Interface: It has only MOSI (PA1 or PC2), MISO (PA2 or PC1), SCK (PA3 or PC0), SS (PA4 or PC3) .
* **TWI** - Two Wire Interface (I2C): It has SDA (PB1 or PA1) and SCL (PB0 or PA2).

**HELLO DISTANCE**


Since I had already designed the circuit for the ATtiny1614, I would only have to change it for the ATtiny3216. There is no footprint. I search Octopart and nothing. At the end I find it on the [SnapEDA page.](https://www.snapeda.com/parts/ATTINY3216-SN/Microchip%20Technology/view-part/?ref=search&t=Tiny3216)

Once the schematic is done, this is the result of the board.

![week09.28](/uploads/220b2145f785c7f46a2b8e103afa425c/week09.28.jpg)

This is the end result of the board. After exporting it as a monochrome image, I use **GIMP** to create the outer border and erase the paths I don't need from the connectors.

![week09.29](/uploads/683f61a0233317a4321ad961905d58c6/week09.29.jpg)

And this is the result of the board, with the VL53L0X module

![week09.31](/uploads/1bd67cb5b0a83b5b07e794407cd563d4/week09.31.jpg)

**PROGRAMMING: ARDUINO + LINUX.**

I use one of the examples that the Adafruit library brings you. Configure the Arduino for the ATtiny3216.

![week09.32](/uploads/e6a239fb8665c95fdcdae4f63ceb1704/week09.32.jpg)

    //Adafruit VL53L0X program.
    //Adrian Torres. Fab Academy 2020.

    #include "Adafruit_VL53L0X.h"

    Adafruit_VL53L0X lox = Adafruit_VL53L0X();

    void setup() {
    Serial.begin(115200);

    // wait until serial port opens for native USB devices
    while (! Serial) {
        delay(1);
    }
  
    Serial.println("Adafruit VL53L0X test");
    if (!lox.begin()) {
        Serial.println(F("Failed to boot VL53L0X"));
        while(1);
    }
    // power 
    Serial.println(F("VL53L0X API Simple Ranging example\n\n")); 
    }

    void loop() {
    VL53L0X_RangingMeasurementData_t measure;
    
    Serial.print("Reading a measurement... ");
    lox.rangingTest(&measure, false); // pass in 'true' to get debug data printout!

    if (measure.RangeStatus != 4) {  // phase failures have incorrect data
        Serial.print("Distance (mm): "); Serial.println(measure.RangeMilliMeter);
      } else {
        Serial.println(" out of range ");
    }
    
    delay(100);
    }


Using the PyUPDI and the FT230XS programmer and the converter for UPDI I load the .hex program.

Program the board using python -> run 

          sudo python3 pyupdi.py -d tiny3216 -c /dev/ttyUSB0 -b 19200 -f vl53l0x.ino.hex -v

After, listen the serial port 

            python -m serial.tools.miniterm /dev/ttyUSB0 115200



You can find more information about this board on my page.

http://fabacademy.org/2020/labs/leon/students/adrian-torres/week09.html