**DATASHEET**

I combine the Datasheet image with the one from the [SpenceKonde website](https://github.com/SpenceKonde/megaTinyCore/blob/master/megaavr/extras/ATtiny_x14.md) on the ATtiny1614.

* 14 pin package.
* Two internal clocks 16 and 20 MHz.
* 16 KB Flash Memory.
* 256 B EEPROM.
* 2 KB SRAM.
* Maximum voltage: 6V; minimum voltage -0.5 V.

After looking at the basic features, you will find the pinning of the microcontroller.

![week08.04](/uploads/42085ccf768761cb72f41c66e4d2e48d/week08.04.jpg)

* VDD: Supply voltage.
* GND: Ground.
* Digital pins: Port A: PA0, PA1, PA2, PA3, PA4, PA5, PA6, PA7. Port B: PB0, PB1, PB2, PB3.
* Analog pins: PA1, PA2, PA3, PA4, PA5, PA6, PA7. Port B: PB0, PB1.
* UPDI Programming pin: PA0 (physical pin number 10).
* External Clock Pin: PA3.

All I/O pins can be configured with **internal pullup resistance**.

Within the communications section there are different types and their pins are different. It is clear that the different communication protocols cannot all be used at the same time, because they have pins in common.

* **USART** - Universal Synchronous and Asynchronous Receiver and Transmitter: It has the RX (PB2 or PA2) and the TX (PB3 or PA1).
* **SPI** - Serial Peripheral Interface: It has only MOSI (PA1), MISO (PA2), SCK (PA3), SS (PA4) .
* **TWI** - Two Wire Interface (I2C): It has SDA (PB1 or PA1) and SCL (PB0 or PA2).


Another important thing that the datasheet is telling us is that you have to keep in mind which kind of input component you are using, digital or analog: for instance, if you are using a temperature sensor (analog component) you have to connect it to an ACD (analog to digital converter) port otherwise the microcontroller isn't able to transform the information that is receiving from the sensor to a digital data.

**HELLO REFLECT / LIGHT**

For the **Hello Reflect / Light** I am going to use the ATtiny 1614. There is no footprint in the Eagle library, so I download it from Octopart [https://octopart.com/attiny1614-ssfr-microchip-82181131?r=spc#PriceAndStock](url)

I am going to use the two types of phototransistor so I take the Visible and the IR with the corresponding LEDs (visible and IR). I modify the schematic and the board in Eagle. 

![schematic](/uploads/a6b8b25282cc99d474e627e297b6efe9/schematic.jpg)

![board](/uploads/547efc725d546c8a1e3d489291ee63ff/board.jpg)

I extract the PNG and edit it with GIMP

![week09.40](/uploads/51be9f9401f3f9b3ae39fcd96bb45d57/week09.40.jpg)

This is the result of the board. On the left the **Hello Reflect** and on the right the **Hello Light.**

![week09.13](/uploads/f36e769b348f8637ec8409eec2408792/week09.13.jpg)

**PROGRAMMING: ARDUINO + LINUX.**

The program for **Hello Reflect** is:



    //QRD1114_Proximity_Example.ino

    //Example sketch for SparkFun's QRD1114 Reflectance Proximity Sensor

    //  (https://www.sparkfun.com/products/246)

    //Jim Lindblom @ SparkFun Electronics

    //May 2, 2016

    //Modified by Adrián Torres Omaña

    //Fab Academy 2020 - Fab Lab León

    //ATtiny1614


    const int Sensor = 1; // Sensor output voltage

    void setup() 
    {
     Serial.begin(115200);

      pinMode(Sensor, INPUT);
    }

    void loop() 
    {
      // Read in the ADC and convert it to a voltage:

      int proximityADC = analogRead(Sensor);

      float proximityV = (float)proximityADC * 5.0 / 1023.0;

      Serial.println(proximityV);

      delay(100);
    }





Using the PyUPDI and the FT230XS programmer and the converter for UPDI I load the .hex program.
Program the board using python -> run 

    **sudo python3 pyupdi.py -d tiny1614 -c /dev/ttyUSB0 -b 19200 -f Hello_Reflect_IR.ino.hex -v**

After, listen the serial port 

    **python -m serial.tools.miniterm /dev/ttyUSB0 115200**






The other program for **Hello Light** is:


    //Original code: Elena Cardiel. Fab Academy 2019.
    //
    //Modified by Adrián Torres. Fab Academy 2020.
    //
    //ATtiny1614

    int sensorPin = 1;    // analog input pin to hook the sensor to

    int sensorValue = 0;  // variable to store the value coming from the sensor
 
    void setup() {

      Serial.begin(115200); // initialize serial communications

    }
 
    void loop() {

      sensorValue = analogRead(sensorPin); // read the value from the sensor

      sensorValue = map(sensorValue, 0, 1024, 1024, 0);

      Serial.println(sensorValue); // print value to Serial Monitor

      //mySerial.println("x"); // print value "x" to Serial Monitor

      delay(500); // short delay so we can actually see the numbers

    }




Using the PyUPDI and the FT230XS programmer and the converter for UPDI I load the .hex program.
Program the board using python -> run 

    **sudo python3 pyupdi.py -d tiny1614 -c /dev/ttyUSB0 -b 19200 -f Hello_phototransistor.ino.hex -v**

After, listen the serial port 

    **python -m serial.tools.miniterm /dev/ttyUSB0 115200**




You can find more information about this board on my page.

http://fabacademy.org/2020/labs/leon/students/adrian-torres/week09.html