**DATASHEET**

I combine the Datasheet image with the one from the [SpenceKonde website](https://github.com/SpenceKonde/megaTinyCore/blob/master/megaavr/extras/ATtiny_x14.md) on the ATtiny1614.

* 14 pin package.
* Two internal clocks 16 and 20 MHz.
* 16 KB Flash Memory.
* 256 B EEPROM.
* 2 KB SRAM.
* Maximum voltage: 6V; minimum voltage -0.5 V.

After looking at the basic features, you will find the pinning of the microcontroller.

![week08.04](/uploads/42085ccf768761cb72f41c66e4d2e48d/week08.04.jpg)

* VDD: Supply voltage.
* GND: Ground.
* Digital pins: Port A: PA0, PA1, PA2, PA3, PA4, PA5, PA6, PA7. Port B: PB0, PB1, PB2, PB3.
* Analog pins: PA1, PA2, PA3, PA4, PA5, PA6, PA7. Port B: PB0, PB1.
* UPDI Programming pin: PA0 (physical pin number 10).
* External Clock Pin: PA3.

All I/O pins can be configured with **internal pullup resistance**.

Within the communications section there are different types and their pins are different. It is clear that the different communication protocols cannot all be used at the same time, because they have pins in common.

* **USART** - Universal Synchronous and Asynchronous Receiver and Transmitter: It has the RX (PB2 or PA2) and the TX (PB3 or PA1).
* **SPI** - Serial Peripheral Interface: It has only MOSI (PA1), MISO (PA2), SCK (PA3), SS (PA4) .
* **TWI** - Two Wire Interface (I2C): It has SDA (PB1 or PA1) and SCL (PB0 or PA2).


Another important thing that the datasheet is telling us is that you have to keep in mind which kind of input component you are using, digital or analog: for instance, if you are using a temperature sensor (analog component) you have to connect it to an ACD (analog to digital converter) port otherwise the microcontroller isn't able to transform the information that is receiving from the sensor to a digital data.

**HELLO SERVO**

For the **Hello Servo** I am going to use the ATtiny 1614. There is no footprint in the Eagle library, so I download it from Octopart [https://octopart.com/attiny1614-ssfr-microchip-82181131?r=spc#PriceAndStock](url)  I'm going to use a 9V battery to power the board, so I need to use a voltage regulator. Looking at the inventory of the Fab Lab León there is the LM2940. We must be careful when we place the component in the schematic, because the pinning does not match and we must look at the Datasheet. In this case I use package SOT223.

![week11.02](/uploads/96018577f82d07634466e7818dd0849c/week11.02.jpg)

For the Hello Servo I will also incorporate the I2C and the Serial Bus (this time with a separate connector). I modify the schematic and the board in Eagle.

![week11.03](/uploads/fb49bd957b780a21a8818299af2e97c0/week11.03.jpg)

I extract the PNG and edit it with GIMP

![week11.04](/uploads/c1265a541679ce43f82a43f561eabac5/week11.04.jpg)

This is the result of the board **Hello Servo.**

![acc0214f6fbf9315-photo-full](/uploads/6c735bedb5d873cf99aac37ce528628d/acc0214f6fbf9315-photo-full.jpg)

And this is the connection of the servo and the 9V battery.

![week11.12](/uploads/a95489d2d8020a4f9978b18687bedb36/week11.12.jpg)

**PROGRAMMING: ARDUINO + LINUX.**

The program for **Hello Servo** is:
    

    //Modified by Adrián Torres Omaña
    //Fab Academy 2020
    //Fab Lab León 

    /* Sweep
     by BARRAGAN 
     This example code is in the public domain.

     modified 8 Nov 2013
     by Scott Fitzgerald
     http://www.arduino.cc/en/Tutorial/Sweep
     */

     #include 

     Servo myservo1;
     Servo myservo2;
     // create servo object to control a servo
     // twelve servo objects can be created on most boards

     int pos = 0;    // variable to store the servo position

     void setup() {
          myservo1.attach(2);  // attaches the servo on pin 2 to the servo object
          myservo2.attach(3);  // attaches the servo on pin 3 to the servo object
     }

     void loop() {
     for (pos = 0; pos <= 180; pos += 1) { // goes from 0 degrees to 180 degrees
          // in steps of 1 degree
        myservo1.write(pos);              // tell servo to go to position in variable 'pos'
        myservo2.write(pos);
        delay(15);                       // waits 15ms for the servo to reach the position
     }
     for (pos = 180; pos >= 0; pos -= 1) { // goes from 180 degrees to 0 degrees
         myservo1.write(pos);              // tell servo to go to position in variable 'pos'
         myservo2.write(pos);
         delay(15);                       // waits 15ms for the servo to reach the position
       }
      }


You can find more information about this board on my page.

http://fabacademy.org/2020/labs/leon/students/adrian-torres/week11.html